aboutsummaryrefslogtreecommitdiffstats
path: root/include/misc.h
diff options
context:
space:
mode:
authorJoerie de Gram <j.de.gram@gmail.com>2011-08-17 15:57:47 +0200
committerJoerie de Gram <j.de.gram@gmail.com>2011-08-17 15:57:47 +0200
commitd3bd80a932e4f76b6cae280c78f118882f3b176d (patch)
treecad99877da53cad9fae5907fd43fe5a79e50ad37 /include/misc.h
parenta3c46bd32430db57b97a1498d3da9a2c01df22ad (diff)
downloadhardware_replicant_libsamsung-ipc-d3bd80a932e4f76b6cae280c78f118882f3b176d.tar.gz
hardware_replicant_libsamsung-ipc-d3bd80a932e4f76b6cae280c78f118882f3b176d.tar.bz2
hardware_replicant_libsamsung-ipc-d3bd80a932e4f76b6cae280c78f118882f3b176d.zip
Rename library to libsamsung-ipc
Diffstat (limited to 'include/misc.h')
-rw-r--r--include/misc.h26
1 files changed, 13 insertions, 13 deletions
diff --git a/include/misc.h b/include/misc.h
index 12c8fc3..3aff7e4 100644
--- a/include/misc.h
+++ b/include/misc.h
@@ -1,39 +1,39 @@
/**
* This file is part of libmsm-h1.
*
* Copyright (C) 2010-2011 Joerie de Gram <j.de.gram@gmail.com>
*
* libmsm-h1 is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* libmsm-h1 is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with libmsm-h1. If not, see <http://www.gnu.org/licenses/>.
+ * along with libsamsung-ipc. If not, see <http://www.gnu.org/licenses/>.
*
*/
#ifndef __MISC_H__
#define __MISC_H__
-#define MSM_MISC_ME_VERSION 0x0A01
-#define MSM_MISC_ME_IMSI 0x0A02
-#define MSM_MISC_ME_SN 0x0A03
-#define MSM_MISC_TIME_INFO 0x0A07
+#define IPC_MISC_ME_VERSION 0x0A01
+#define IPC_MISC_ME_IMSI 0x0A02
+#define IPC_MISC_ME_SN 0x0A03
+#define IPC_MISC_TIME_INFO 0x0A07
-struct msm_misc_me_version {
+struct ipc_misc_me_version {
char sw_version[32];
char hw_version[32];
char cal_date[32];
char misc[32];
} __attribute__((__packed__));
-struct msm_misc_time_info {
+struct ipc_misc_time_info {
unsigned char tz_valid, daylight_valid;
unsigned char year, mon, day;
unsigned char hour, min, sec;
@@ -41,9 +41,9 @@ struct msm_misc_time_info {
char plmn[6];
} __attribute__((__packed__));
-void msm_misc_me_version(int request_id);
-void msm_misc_me_imsi(int request_id);
-void msm_misc_me_sn(int request_id);
+void ipc_misc_me_version(int request_id);
+void ipc_misc_me_imsi(int request_id);
+void ipc_misc_me_sn(int request_id);
#endif
@@ -1,39 +1,39 @@
/**
- * This file is part of libmsm-h1.
+ * This file is part of libsamsung-ipc.
*
* Copyright (C) 2010-2011 Joerie de Gram <j.de.gram@gmail.com>
@@ -1,39 +1,39 @@
* Copyright (C) 2010-2011 Joerie de Gram <j.de.gram@gmail.com>
*
- * libmsm-h1 is free software: you can redistribute it and/or modify
+ * libsamsung-ipc is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
@@ -1,39 +1,39 @@
* (at your option) any later version.
*
- * libmsm-h1 is distributed in the hope that it will be useful,
+ * libsamsung-ipc is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the